from string import Template
from pi_display_webthing.app import App
from pi_display_webthing.display_webthing import run_server



PACKAGENAME = 'pi_display_webthing'
ENTRY_POINT = "display"
DESCRIPTION = "A web connected LCD display module"


UNIT_TEMPLATE = Template('''
[Unit]
Description=$packagename
After=syslog.target network.target

[Service]
Type=simple
ExecStart=$entrypoint --command listen --hostname $hostname --verbose $verbose --port $port --name $name --i2c_address $i2c_address --i2c_expander $i2c_expander
SyslogIdentifier=$packagename
StandardOutput=syslog
StandardError=syslog
Restart=always
RestartSec=30

[Install]
WantedBy=multi-user.target
''')




class DhtApp(App):

    def do_add_argument(self, parser):
        parser.add_argument('--i2c_expander', metavar='i2c_expander', required=False, type=str, help='the name of the port I²C port expander. Supported: PCF8574, MCP23008, MCP23017')
        parser.add_argument('--i2c_address', metavar='i2c_address', required=False, type=str, help='the I²C address of the LCD Module as hex string')
        parser.add_argument('--name', metavar='name', required=False, type=str, default="", help='the name of the display')

    def do_additional_listen_example_params(self):
        return "--name nas --i2c_expander PCF8574 --i2c_address 0x27"

    def do_process_command(self, command:str, hostname: str, port: int, verbose: bool, args) -> bool:
        if command == 'listen' and (args.i2c_expander is not None) and (args.i2c_address is not None):
            print("running " + self.packagename + " on " + hostname + ":" + str(port))
            run_server(hostname, port, args.name, args.i2c_expander, self.to_hex(args.i2c_address), self.description)
            return True
        elif args.command == 'register' and (args.i2c_expander is not None) and (args.i2c_address is not None):
            print("register " + self.packagename  + " on " + hostname + ":" + str(port) + " and starting it")
            unit = UNIT_TEMPLATE.substitute(packagename=self.packagename, entrypoint=self.entrypoint, hostname=hostname, port=port, verbose=verbose, name=args.name, i2c_expander=args.i2c_expander, i2c_address=args.i2c_address)
            self.unit.register(hostname, port, unit)
            return True
        else:
            return False

    def to_hex(self, hexString: str) -> int:
        if hexString.startswith("0x"):
            return int(hexString, 16)
        else:
            return int(hexString)


def main():
    DhtApp(PACKAGENAME, ENTRY_POINT, DESCRIPTION).handle_command()


if __name__ == '__main__':
    main()
